export * from '@edene/hooks';
import { createContext, useContext, useState } from 'react';
import { jsx } from '@emotion/react/jsx-runtime';

// Arrays of colours should have pillar colors first
var colors = {
  reds: ['#660505', '#8B0000', '#AB0613', '#C70000', '#FF5943', '#FF9081', '#FFBAC8', '#FFF4F2'],
  oranges: ['#672005', '#8D2700', '#C74600', '#E05E00', '#FF7F0F', '#FF9941', '#F9B376', '#FEF9F5'],
  blues: ['#003C60', '#004E7C', '#005689', '#0077B6', '#00B2FF', '#90DCFF', '#F1F8FC', '#001536', '#041F4A', '#052962', '#007ABC', '#506991', '#C1D8FC', '#0093E0' //focus
  ],
  browns: ['#2B2625', '#3E3323', '#574835', '#6B5840', '#866D50', '#A1845C', '#EACCA0', '#E7D4B9', '#EFE8DD', '#FBF6EF'],
  pinks: ['#510043', '#650054', '#7D0068', '#BB3B80', '#FFABDB', '#FEC8D3', '#FEEEF7'],
  greens: ['#185E36', '#22874D', '#58D08B', '#4B8878', '#65A897', '#69D1CA'],
  grays: ['#212529', '#343a40', '#495057', '#868e96', '#adb5bd', '#ced4da', '#dee2e6', '#e9ecef', '#f1f3f5', '#F8F9FA', '#222527', '#303538', '#3F464A', '#595C5F', '#9DA0A2', '#ABC2C9', '#E4E5E8', '#EFF1F2']
};
var grays = {
  0: colors.grays[0],
  1: colors.grays[1],
  2: colors.grays[2],
  3: colors.grays[3],
  4: colors.grays[4],
  5: colors.grays[5],
  6: colors.grays[6],
  7: colors.grays[7],
  8: colors.grays[8],
  9: colors.grays[9]
};
var brandColor = 'rgb(250, 82, 82)';
var brandHover = 'rgb(240, 62, 62)';
var white = '#FCFCFC';
var black = '#1C1E20';
var info = colors.blues[3];
var error = colors.reds[3];
var success = colors.greens[1];
var focus = colors.blues[13];
var background = {
  primary: '#161616',
  secondary: '#e5e5e5',
  toolbar: '#161616'
};
var altBackground = {
  primary: '#161616',
  secondary: '#e5e5e5',
  toolbar: '#ffffff'
};
var text = {
  primary: grays[0],
  supporting: grays[4],
  success: success,
  error: error,
  ctaPrimary: grays[9],
  anchorSecondary: grays[7],
  userInput: grays[7],
  inputLabel: grays[7],
  inputError: grays[7],
  inputLabelSupporting: grays[4],
  groupLabel: grays[7],
  groupLabelSupporting: grays[4],
  toolbar: '#f4f4f4'
};
var altText = {
  primary: grays[7],
  supporting: grays[4],
  success: success,
  error: error,
  ctaPrimary: grays[9],
  anchorSecondary: grays[7],
  userInput: grays[7],
  inputLabel: grays[7],
  inputError: grays[7],
  inputLabelSupporting: grays[4],
  groupLabel: grays[7],
  groupLabelSupporting: grays[4],
  toolbar: '#1C1E20'
};
var border = {
  primary: grays[5],
  secondary: grays[6],
  success: success,
  error: error,
  input: grays[5],
  focusHalo: focus
};
var fill = {
  headerAction: '#ffffff'
};
var altFill = {
  headerAction: '#161616'
};
var colorsPalette = {
  success: {
    light: '#E1F9F5',
    color: 'rgb(48, 144, 142)',
    dark: '#155724',
    hover: 'rgb(44, 122, 123)'
  },
  info: {
    light: '#EBF6FA',
    color: '#2A789A',
    dark: '#155724',
    hover: 'rgb(44, 122, 123)'
  },
  danger: {
    light: '#f8d7da',
    color: '#DC3545',
    dark: '#721c24',
    hover: '#C82333'
  },
  gray: {
    light: '#F2F2F2',
    color: '#6F6F6F',
    hover: 'rgb(226, 232, 240)'
  },
  dark: {
    light: '#f8d7da',
    color: '#100F10',
    hover: '#485963'
  },
  teal: {
    light: '#f8d7da',
    color: 'rgb(48, 144, 142)',
    hover: 'rgb(44, 122, 123)'
  },
  pink: {
    light: '#f8d7da',
    color: 'rgb(227, 227, 232)',
    hover: 'transparent'
  },
  transparent: {
    light: '#f8d7da',
    color: 'transparent',
    hover: 'transparent'
  }
};

var visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
var focusHalo = "\n  outline: 2px solid ".concat(border.focusHalo, ";\n  outline-offset: -2px;\n");
var disabled = "\n    opacity: 0.4;\n    cursor: not-allowed;\n    box-shadow: none;\n";
var descriptionId = function descriptionId(id) {
  return "".concat(id, "_description");
};
var sourceIdIndex = 0;
var generateSourceId = function generateSourceId() {
  return "component-".concat(sourceIdIndex++);
};

var breakpoints = {
  mobile: 320,
  mobileMedium: 375,
  mobileLandscape: 480,
  phablet: 660,
  tablet: 768,
  desktop: 980,
  leftCol: 1140,
  wide: 1300
}; // utility functions to set media queries

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
}; // breakpoints calculus


var from = {
  mobile: minWidth(breakpoints.mobile),
  mobileMedium: minWidth(breakpoints.mobileMedium),
  mobileLandscape: minWidth(breakpoints.mobileLandscape),
  phablet: minWidth(breakpoints.phablet),
  tablet: minWidth(breakpoints.tablet),
  desktop: minWidth(breakpoints.desktop),
  leftCol: minWidth(breakpoints.leftCol),
  wide: minWidth(breakpoints.wide)
}; // e.g. until.*

var until = {
  mobile: maxWidth(breakpoints.mobile),
  mobileMedium: maxWidth(breakpoints.mobileMedium),
  mobileLandscape: maxWidth(breakpoints.mobileLandscape),
  phablet: maxWidth(breakpoints.phablet),
  tablet: maxWidth(breakpoints.tablet),
  desktop: maxWidth(breakpoints.desktop),
  leftCol: maxWidth(breakpoints.leftCol),
  wide: maxWidth(breakpoints.wide)
};

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var check = function (it) {
  return it && it.Math == Math && it;
};

// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global$b =
  // eslint-disable-next-line no-undef
  check(typeof globalThis == 'object' && globalThis) ||
  check(typeof window == 'object' && window) ||
  check(typeof self == 'object' && self) ||
  check(typeof commonjsGlobal == 'object' && commonjsGlobal) ||
  // eslint-disable-next-line no-new-func
  Function('return this')();

var objectGetOwnPropertyDescriptor = {};

var fails$8 = function (exec) {
  try {
    return !!exec();
  } catch (error) {
    return true;
  }
};

var fails$7 = fails$8;

// Thank's IE8 for his funny defineProperty
var descriptors = !fails$7(function () {
  return Object.defineProperty({}, 1, { get: function () { return 7; } })[1] != 7;
});

var objectPropertyIsEnumerable = {};

var nativePropertyIsEnumerable = {}.propertyIsEnumerable;
var getOwnPropertyDescriptor$1 = Object.getOwnPropertyDescriptor;

// Nashorn ~ JDK8 bug
var NASHORN_BUG = getOwnPropertyDescriptor$1 && !nativePropertyIsEnumerable.call({ 1: 2 }, 1);

// `Object.prototype.propertyIsEnumerable` method implementation
// https://tc39.github.io/ecma262/#sec-object.prototype.propertyisenumerable
objectPropertyIsEnumerable.f = NASHORN_BUG ? function propertyIsEnumerable(V) {
  var descriptor = getOwnPropertyDescriptor$1(this, V);
  return !!descriptor && descriptor.enumerable;
} : nativePropertyIsEnumerable;

var createPropertyDescriptor$4 = function (bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value: value
  };
};

var toString = {}.toString;

var classofRaw$1 = function (it) {
  return toString.call(it).slice(8, -1);
};

var fails$6 = fails$8;
var classof$2 = classofRaw$1;

var split = ''.split;

// fallback for non-array-like ES3 and non-enumerable old V8 strings
var indexedObject = fails$6(function () {
  // throws an error in rhino, see https://github.com/mozilla/rhino/issues/346
  // eslint-disable-next-line no-prototype-builtins
  return !Object('z').propertyIsEnumerable(0);
}) ? function (it) {
  return classof$2(it) == 'String' ? split.call(it, '') : Object(it);
} : Object;

// `RequireObjectCoercible` abstract operation
// https://tc39.github.io/ecma262/#sec-requireobjectcoercible
var requireObjectCoercible$2 = function (it) {
  if (it == undefined) throw TypeError("Can't call method on " + it);
  return it;
};

// toObject with fallback for non-array-like ES3 strings
var IndexedObject$1 = indexedObject;
var requireObjectCoercible$1 = requireObjectCoercible$2;

var toIndexedObject$4 = function (it) {
  return IndexedObject$1(requireObjectCoercible$1(it));
};

var isObject$5 = function (it) {
  return typeof it === 'object' ? it !== null : typeof it === 'function';
};

var isObject$4 = isObject$5;

// `ToPrimitive` abstract operation
// https://tc39.github.io/ecma262/#sec-toprimitive
// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
var toPrimitive$3 = function (input, PREFERRED_STRING) {
  if (!isObject$4(input)) return input;
  var fn, val;
  if (PREFERRED_STRING && typeof (fn = input.toString) == 'function' && !isObject$4(val = fn.call(input))) return val;
  if (typeof (fn = input.valueOf) == 'function' && !isObject$4(val = fn.call(input))) return val;
  if (!PREFERRED_STRING && typeof (fn = input.toString) == 'function' && !isObject$4(val = fn.call(input))) return val;
  throw TypeError("Can't convert object to primitive value");
};

var hasOwnProperty = {}.hasOwnProperty;

var has$a = function (it, key) {
  return hasOwnProperty.call(it, key);
};

var global$a = global$b;
var isObject$3 = isObject$5;

var document$1 = global$a.document;
// typeof document.createElement is 'object' in old IE
var EXISTS = isObject$3(document$1) && isObject$3(document$1.createElement);

var documentCreateElement$1 = function (it) {
  return EXISTS ? document$1.createElement(it) : {};
};

var DESCRIPTORS$6 = descriptors;
var fails$5 = fails$8;
var createElement = documentCreateElement$1;

// Thank's IE8 for his funny defineProperty
var ie8DomDefine = !DESCRIPTORS$6 && !fails$5(function () {
  return Object.defineProperty(createElement('div'), 'a', {
    get: function () { return 7; }
  }).a != 7;
});

var DESCRIPTORS$5 = descriptors;
var propertyIsEnumerableModule$1 = objectPropertyIsEnumerable;
var createPropertyDescriptor$3 = createPropertyDescriptor$4;
var toIndexedObject$3 = toIndexedObject$4;
var toPrimitive$2 = toPrimitive$3;
var has$9 = has$a;
var IE8_DOM_DEFINE$1 = ie8DomDefine;

var nativeGetOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

// `Object.getOwnPropertyDescriptor` method
// https://tc39.github.io/ecma262/#sec-object.getownpropertydescriptor
objectGetOwnPropertyDescriptor.f = DESCRIPTORS$5 ? nativeGetOwnPropertyDescriptor : function getOwnPropertyDescriptor(O, P) {
  O = toIndexedObject$3(O);
  P = toPrimitive$2(P, true);
  if (IE8_DOM_DEFINE$1) try {
    return nativeGetOwnPropertyDescriptor(O, P);
  } catch (error) { /* empty */ }
  if (has$9(O, P)) return createPropertyDescriptor$3(!propertyIsEnumerableModule$1.f.call(O, P), O[P]);
};

var objectDefineProperty = {};

var isObject$2 = isObject$5;

var anObject$7 = function (it) {
  if (!isObject$2(it)) {
    throw TypeError(String(it) + ' is not an object');
  } return it;
};

var DESCRIPTORS$4 = descriptors;
var IE8_DOM_DEFINE = ie8DomDefine;
var anObject$6 = anObject$7;
var toPrimitive$1 = toPrimitive$3;

var nativeDefineProperty = Object.defineProperty;

// `Object.defineProperty` method
// https://tc39.github.io/ecma262/#sec-object.defineproperty
objectDefineProperty.f = DESCRIPTORS$4 ? nativeDefineProperty : function defineProperty(O, P, Attributes) {
  anObject$6(O);
  P = toPrimitive$1(P, true);
  anObject$6(Attributes);
  if (IE8_DOM_DEFINE) try {
    return nativeDefineProperty(O, P, Attributes);
  } catch (error) { /* empty */ }
  if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported');
  if ('value' in Attributes) O[P] = Attributes.value;
  return O;
};

var DESCRIPTORS$3 = descriptors;
var definePropertyModule$4 = objectDefineProperty;
var createPropertyDescriptor$2 = createPropertyDescriptor$4;

var createNonEnumerableProperty$6 = DESCRIPTORS$3 ? function (object, key, value) {
  return definePropertyModule$4.f(object, key, createPropertyDescriptor$2(1, value));
} : function (object, key, value) {
  object[key] = value;
  return object;
};

var redefine$2 = {exports: {}};

var global$9 = global$b;
var createNonEnumerableProperty$5 = createNonEnumerableProperty$6;

var setGlobal$3 = function (key, value) {
  try {
    createNonEnumerableProperty$5(global$9, key, value);
  } catch (error) {
    global$9[key] = value;
  } return value;
};

var global$8 = global$b;
var setGlobal$2 = setGlobal$3;

var SHARED = '__core-js_shared__';
var store$3 = global$8[SHARED] || setGlobal$2(SHARED, {});

var sharedStore = store$3;

var store$2 = sharedStore;

var functionToString = Function.toString;

// this helper broken in `3.4.1-3.4.4`, so we can't use `shared` helper
if (typeof store$2.inspectSource != 'function') {
  store$2.inspectSource = function (it) {
    return functionToString.call(it);
  };
}

var inspectSource$2 = store$2.inspectSource;

var global$7 = global$b;
var inspectSource$1 = inspectSource$2;

var WeakMap$1 = global$7.WeakMap;

var nativeWeakMap = typeof WeakMap$1 === 'function' && /native code/.test(inspectSource$1(WeakMap$1));

var shared$2 = {exports: {}};

var store$1 = sharedStore;

(shared$2.exports = function (key, value) {
  return store$1[key] || (store$1[key] = value !== undefined ? value : {});
})('versions', []).push({
  version: '3.6.5',
  mode: 'global',
  copyright: '© 2020 Denis Pushkarev (zloirock.ru)'
});

var id = 0;
var postfix = Math.random();

var uid$2 = function (key) {
  return 'Symbol(' + String(key === undefined ? '' : key) + ')_' + (++id + postfix).toString(36);
};

var shared$1 = shared$2.exports;
var uid$1 = uid$2;

var keys = shared$1('keys');

var sharedKey$3 = function (key) {
  return keys[key] || (keys[key] = uid$1(key));
};

var hiddenKeys$4 = {};

var NATIVE_WEAK_MAP = nativeWeakMap;
var global$6 = global$b;
var isObject$1 = isObject$5;
var createNonEnumerableProperty$4 = createNonEnumerableProperty$6;
var objectHas = has$a;
var sharedKey$2 = sharedKey$3;
var hiddenKeys$3 = hiddenKeys$4;

var WeakMap = global$6.WeakMap;
var set, get, has$8;

var enforce = function (it) {
  return has$8(it) ? get(it) : set(it, {});
};

var getterFor = function (TYPE) {
  return function (it) {
    var state;
    if (!isObject$1(it) || (state = get(it)).type !== TYPE) {
      throw TypeError('Incompatible receiver, ' + TYPE + ' required');
    } return state;
  };
};

if (NATIVE_WEAK_MAP) {
  var store = new WeakMap();
  var wmget = store.get;
  var wmhas = store.has;
  var wmset = store.set;
  set = function (it, metadata) {
    wmset.call(store, it, metadata);
    return metadata;
  };
  get = function (it) {
    return wmget.call(store, it) || {};
  };
  has$8 = function (it) {
    return wmhas.call(store, it);
  };
} else {
  var STATE = sharedKey$2('state');
  hiddenKeys$3[STATE] = true;
  set = function (it, metadata) {
    createNonEnumerableProperty$4(it, STATE, metadata);
    return metadata;
  };
  get = function (it) {
    return objectHas(it, STATE) ? it[STATE] : {};
  };
  has$8 = function (it) {
    return objectHas(it, STATE);
  };
}

var internalState = {
  set: set,
  get: get,
  has: has$8,
  enforce: enforce,
  getterFor: getterFor
};

var global$5 = global$b;
var createNonEnumerableProperty$3 = createNonEnumerableProperty$6;
var has$7 = has$a;
var setGlobal$1 = setGlobal$3;
var inspectSource = inspectSource$2;
var InternalStateModule$1 = internalState;

var getInternalState$1 = InternalStateModule$1.get;
var enforceInternalState = InternalStateModule$1.enforce;
var TEMPLATE = String(String).split('String');

(redefine$2.exports = function (O, key, value, options) {
  var unsafe = options ? !!options.unsafe : false;
  var simple = options ? !!options.enumerable : false;
  var noTargetGet = options ? !!options.noTargetGet : false;
  if (typeof value == 'function') {
    if (typeof key == 'string' && !has$7(value, 'name')) createNonEnumerableProperty$3(value, 'name', key);
    enforceInternalState(value).source = TEMPLATE.join(typeof key == 'string' ? key : '');
  }
  if (O === global$5) {
    if (simple) O[key] = value;
    else setGlobal$1(key, value);
    return;
  } else if (!unsafe) {
    delete O[key];
  } else if (!noTargetGet && O[key]) {
    simple = true;
  }
  if (simple) O[key] = value;
  else createNonEnumerableProperty$3(O, key, value);
// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
})(Function.prototype, 'toString', function toString() {
  return typeof this == 'function' && getInternalState$1(this).source || inspectSource(this);
});

var global$4 = global$b;

var path$1 = global$4;

var path = path$1;
var global$3 = global$b;

var aFunction$2 = function (variable) {
  return typeof variable == 'function' ? variable : undefined;
};

var getBuiltIn$2 = function (namespace, method) {
  return arguments.length < 2 ? aFunction$2(path[namespace]) || aFunction$2(global$3[namespace])
    : path[namespace] && path[namespace][method] || global$3[namespace] && global$3[namespace][method];
};

var objectGetOwnPropertyNames = {};

var ceil = Math.ceil;
var floor = Math.floor;

// `ToInteger` abstract operation
// https://tc39.github.io/ecma262/#sec-tointeger
var toInteger$2 = function (argument) {
  return isNaN(argument = +argument) ? 0 : (argument > 0 ? floor : ceil)(argument);
};

var toInteger$1 = toInteger$2;

var min$1 = Math.min;

// `ToLength` abstract operation
// https://tc39.github.io/ecma262/#sec-tolength
var toLength$2 = function (argument) {
  return argument > 0 ? min$1(toInteger$1(argument), 0x1FFFFFFFFFFFFF) : 0; // 2 ** 53 - 1 == 9007199254740991
};

var toInteger = toInteger$2;

var max = Math.max;
var min = Math.min;

// Helper for a popular repeating case of the spec:
// Let integer be ? ToInteger(index).
// If integer < 0, let result be max((length + integer), 0); else let result be min(integer, length).
var toAbsoluteIndex$1 = function (index, length) {
  var integer = toInteger(index);
  return integer < 0 ? max(integer + length, 0) : min(integer, length);
};

var toIndexedObject$2 = toIndexedObject$4;
var toLength$1 = toLength$2;
var toAbsoluteIndex = toAbsoluteIndex$1;

// `Array.prototype.{ indexOf, includes }` methods implementation
var createMethod = function (IS_INCLUDES) {
  return function ($this, el, fromIndex) {
    var O = toIndexedObject$2($this);
    var length = toLength$1(O.length);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    // Array#includes uses SameValueZero equality algorithm
    // eslint-disable-next-line no-self-compare
    if (IS_INCLUDES && el != el) while (length > index) {
      value = O[index++];
      // eslint-disable-next-line no-self-compare
      if (value != value) return true;
    // Array#indexOf ignores holes, Array#includes - not
    } else for (;length > index; index++) {
      if ((IS_INCLUDES || index in O) && O[index] === el) return IS_INCLUDES || index || 0;
    } return !IS_INCLUDES && -1;
  };
};

var arrayIncludes = {
  // `Array.prototype.includes` method
  // https://tc39.github.io/ecma262/#sec-array.prototype.includes
  includes: createMethod(true),
  // `Array.prototype.indexOf` method
  // https://tc39.github.io/ecma262/#sec-array.prototype.indexof
  indexOf: createMethod(false)
};

var has$6 = has$a;
var toIndexedObject$1 = toIndexedObject$4;
var indexOf = arrayIncludes.indexOf;
var hiddenKeys$2 = hiddenKeys$4;

var objectKeysInternal = function (object, names) {
  var O = toIndexedObject$1(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O) !has$6(hiddenKeys$2, key) && has$6(O, key) && result.push(key);
  // Don't enum bug & hidden keys
  while (names.length > i) if (has$6(O, key = names[i++])) {
    ~indexOf(result, key) || result.push(key);
  }
  return result;
};

// IE8- don't enum bug keys
var enumBugKeys$3 = [
  'constructor',
  'hasOwnProperty',
  'isPrototypeOf',
  'propertyIsEnumerable',
  'toLocaleString',
  'toString',
  'valueOf'
];

var internalObjectKeys$1 = objectKeysInternal;
var enumBugKeys$2 = enumBugKeys$3;

var hiddenKeys$1 = enumBugKeys$2.concat('length', 'prototype');

// `Object.getOwnPropertyNames` method
// https://tc39.github.io/ecma262/#sec-object.getownpropertynames
objectGetOwnPropertyNames.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
  return internalObjectKeys$1(O, hiddenKeys$1);
};

var objectGetOwnPropertySymbols = {};

objectGetOwnPropertySymbols.f = Object.getOwnPropertySymbols;

var getBuiltIn$1 = getBuiltIn$2;
var getOwnPropertyNamesModule = objectGetOwnPropertyNames;
var getOwnPropertySymbolsModule$1 = objectGetOwnPropertySymbols;
var anObject$5 = anObject$7;

// all object keys, includes non-enumerable and symbols
var ownKeys$1 = getBuiltIn$1('Reflect', 'ownKeys') || function ownKeys(it) {
  var keys = getOwnPropertyNamesModule.f(anObject$5(it));
  var getOwnPropertySymbols = getOwnPropertySymbolsModule$1.f;
  return getOwnPropertySymbols ? keys.concat(getOwnPropertySymbols(it)) : keys;
};

var has$5 = has$a;
var ownKeys = ownKeys$1;
var getOwnPropertyDescriptorModule = objectGetOwnPropertyDescriptor;
var definePropertyModule$3 = objectDefineProperty;

var copyConstructorProperties$1 = function (target, source) {
  var keys = ownKeys(source);
  var defineProperty = definePropertyModule$3.f;
  var getOwnPropertyDescriptor = getOwnPropertyDescriptorModule.f;
  for (var i = 0; i < keys.length; i++) {
    var key = keys[i];
    if (!has$5(target, key)) defineProperty(target, key, getOwnPropertyDescriptor(source, key));
  }
};

var fails$4 = fails$8;

var replacement = /#|\.prototype\./;

var isForced$1 = function (feature, detection) {
  var value = data[normalize(feature)];
  return value == POLYFILL ? true
    : value == NATIVE ? false
    : typeof detection == 'function' ? fails$4(detection)
    : !!detection;
};

var normalize = isForced$1.normalize = function (string) {
  return String(string).replace(replacement, '.').toLowerCase();
};

var data = isForced$1.data = {};
var NATIVE = isForced$1.NATIVE = 'N';
var POLYFILL = isForced$1.POLYFILL = 'P';

var isForced_1 = isForced$1;

var global$2 = global$b;
var getOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;
var createNonEnumerableProperty$2 = createNonEnumerableProperty$6;
var redefine$1 = redefine$2.exports;
var setGlobal = setGlobal$3;
var copyConstructorProperties = copyConstructorProperties$1;
var isForced = isForced_1;

/*
  options.target      - name of the target object
  options.global      - target is the global object
  options.stat        - export as static methods of target
  options.proto       - export as prototype methods of target
  options.real        - real prototype method for the `pure` version
  options.forced      - export even if the native feature is available
  options.bind        - bind methods to the target, required for the `pure` version
  options.wrap        - wrap constructors to preventing global pollution, required for the `pure` version
  options.unsafe      - use the simple assignment of property instead of delete + defineProperty
  options.sham        - add a flag to not completely full polyfills
  options.enumerable  - export as enumerable property
  options.noTargetGet - prevent calling a getter on target
*/
var _export = function (options, source) {
  var TARGET = options.target;
  var GLOBAL = options.global;
  var STATIC = options.stat;
  var FORCED, target, key, targetProperty, sourceProperty, descriptor;
  if (GLOBAL) {
    target = global$2;
  } else if (STATIC) {
    target = global$2[TARGET] || setGlobal(TARGET, {});
  } else {
    target = (global$2[TARGET] || {}).prototype;
  }
  if (target) for (key in source) {
    sourceProperty = source[key];
    if (options.noTargetGet) {
      descriptor = getOwnPropertyDescriptor(target, key);
      targetProperty = descriptor && descriptor.value;
    } else targetProperty = target[key];
    FORCED = isForced(GLOBAL ? key : TARGET + (STATIC ? '.' : '#') + key, options.forced);
    // contained in target
    if (!FORCED && targetProperty !== undefined) {
      if (typeof sourceProperty === typeof targetProperty) continue;
      copyConstructorProperties(sourceProperty, targetProperty);
    }
    // add a flag to not completely full polyfills
    if (options.sham || (targetProperty && targetProperty.sham)) {
      createNonEnumerableProperty$2(sourceProperty, 'sham', true);
    }
    // extend global
    redefine$1(target, key, sourceProperty, options);
  }
};

var fails$3 = fails$8;

var nativeSymbol = !!Object.getOwnPropertySymbols && !fails$3(function () {
  // Chrome 38 Symbol has incorrect toString conversion
  // eslint-disable-next-line no-undef
  return !String(Symbol());
});

var NATIVE_SYMBOL$1 = nativeSymbol;

var useSymbolAsUid = NATIVE_SYMBOL$1
  // eslint-disable-next-line no-undef
  && !Symbol.sham
  // eslint-disable-next-line no-undef
  && typeof Symbol.iterator == 'symbol';

var global$1 = global$b;
var shared = shared$2.exports;
var has$4 = has$a;
var uid = uid$2;
var NATIVE_SYMBOL = nativeSymbol;
var USE_SYMBOL_AS_UID = useSymbolAsUid;

var WellKnownSymbolsStore = shared('wks');
var Symbol$1 = global$1.Symbol;
var createWellKnownSymbol = USE_SYMBOL_AS_UID ? Symbol$1 : Symbol$1 && Symbol$1.withoutSetter || uid;

var wellKnownSymbol$8 = function (name) {
  if (!has$4(WellKnownSymbolsStore, name)) {
    if (NATIVE_SYMBOL && has$4(Symbol$1, name)) WellKnownSymbolsStore[name] = Symbol$1[name];
    else WellKnownSymbolsStore[name] = createWellKnownSymbol('Symbol.' + name);
  } return WellKnownSymbolsStore[name];
};

var internalObjectKeys = objectKeysInternal;
var enumBugKeys$1 = enumBugKeys$3;

// `Object.keys` method
// https://tc39.github.io/ecma262/#sec-object.keys
var objectKeys$2 = Object.keys || function keys(O) {
  return internalObjectKeys(O, enumBugKeys$1);
};

var DESCRIPTORS$2 = descriptors;
var definePropertyModule$2 = objectDefineProperty;
var anObject$4 = anObject$7;
var objectKeys$1 = objectKeys$2;

// `Object.defineProperties` method
// https://tc39.github.io/ecma262/#sec-object.defineproperties
var objectDefineProperties = DESCRIPTORS$2 ? Object.defineProperties : function defineProperties(O, Properties) {
  anObject$4(O);
  var keys = objectKeys$1(Properties);
  var length = keys.length;
  var index = 0;
  var key;
  while (length > index) definePropertyModule$2.f(O, key = keys[index++], Properties[key]);
  return O;
};

var getBuiltIn = getBuiltIn$2;

var html$1 = getBuiltIn('document', 'documentElement');

var anObject$3 = anObject$7;
var defineProperties = objectDefineProperties;
var enumBugKeys = enumBugKeys$3;
var hiddenKeys = hiddenKeys$4;
var html = html$1;
var documentCreateElement = documentCreateElement$1;
var sharedKey$1 = sharedKey$3;

var GT = '>';
var LT = '<';
var PROTOTYPE = 'prototype';
var SCRIPT = 'script';
var IE_PROTO$1 = sharedKey$1('IE_PROTO');

var EmptyConstructor = function () { /* empty */ };

var scriptTag = function (content) {
  return LT + SCRIPT + GT + content + LT + '/' + SCRIPT + GT;
};

// Create object with fake `null` prototype: use ActiveX Object with cleared prototype
var NullProtoObjectViaActiveX = function (activeXDocument) {
  activeXDocument.write(scriptTag(''));
  activeXDocument.close();
  var temp = activeXDocument.parentWindow.Object;
  activeXDocument = null; // avoid memory leak
  return temp;
};

// Create object with fake `null` prototype: use iframe Object with cleared prototype
var NullProtoObjectViaIFrame = function () {
  // Thrash, waste and sodomy: IE GC bug
  var iframe = documentCreateElement('iframe');
  var JS = 'java' + SCRIPT + ':';
  var iframeDocument;
  iframe.style.display = 'none';
  html.appendChild(iframe);
  // https://github.com/zloirock/core-js/issues/475
  iframe.src = String(JS);
  iframeDocument = iframe.contentWindow.document;
  iframeDocument.open();
  iframeDocument.write(scriptTag('document.F=Object'));
  iframeDocument.close();
  return iframeDocument.F;
};

// Check for document.domain and active x support
// No need to use active x approach when document.domain is not set
// see https://github.com/es-shims/es5-shim/issues/150
// variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
// avoid IE GC bug
var activeXDocument;
var NullProtoObject = function () {
  try {
    /* global ActiveXObject */
    activeXDocument = document.domain && new ActiveXObject('htmlfile');
  } catch (error) { /* ignore */ }
  NullProtoObject = activeXDocument ? NullProtoObjectViaActiveX(activeXDocument) : NullProtoObjectViaIFrame();
  var length = enumBugKeys.length;
  while (length--) delete NullProtoObject[PROTOTYPE][enumBugKeys[length]];
  return NullProtoObject();
};

hiddenKeys[IE_PROTO$1] = true;

// `Object.create` method
// https://tc39.github.io/ecma262/#sec-object.create
var objectCreate = Object.create || function create(O, Properties) {
  var result;
  if (O !== null) {
    EmptyConstructor[PROTOTYPE] = anObject$3(O);
    result = new EmptyConstructor();
    EmptyConstructor[PROTOTYPE] = null;
    // add "__proto__" for Object.getPrototypeOf polyfill
    result[IE_PROTO$1] = O;
  } else result = NullProtoObject();
  return Properties === undefined ? result : defineProperties(result, Properties);
};

var wellKnownSymbol$7 = wellKnownSymbol$8;
var create$1 = objectCreate;
var definePropertyModule$1 = objectDefineProperty;

var UNSCOPABLES = wellKnownSymbol$7('unscopables');
var ArrayPrototype$1 = Array.prototype;

// Array.prototype[@@unscopables]
// https://tc39.github.io/ecma262/#sec-array.prototype-@@unscopables
if (ArrayPrototype$1[UNSCOPABLES] == undefined) {
  definePropertyModule$1.f(ArrayPrototype$1, UNSCOPABLES, {
    configurable: true,
    value: create$1(null)
  });
}

// add a key to Array.prototype[@@unscopables]
var addToUnscopables$2 = function (key) {
  ArrayPrototype$1[UNSCOPABLES][key] = true;
};

var DESCRIPTORS$1 = descriptors;
var fails$2 = fails$8;
var has$3 = has$a;

var defineProperty$2 = Object.defineProperty;
var cache = {};

var thrower = function (it) { throw it; };

var arrayMethodUsesToLength$1 = function (METHOD_NAME, options) {
  if (has$3(cache, METHOD_NAME)) return cache[METHOD_NAME];
  if (!options) options = {};
  var method = [][METHOD_NAME];
  var ACCESSORS = has$3(options, 'ACCESSORS') ? options.ACCESSORS : false;
  var argument0 = has$3(options, 0) ? options[0] : thrower;
  var argument1 = has$3(options, 1) ? options[1] : undefined;

  return cache[METHOD_NAME] = !!method && !fails$2(function () {
    if (ACCESSORS && !DESCRIPTORS$1) return true;
    var O = { length: -1 };

    if (ACCESSORS) defineProperty$2(O, 1, { enumerable: true, get: thrower });
    else O[1] = 1;

    method.call(O, argument0, argument1);
  });
};

var $$3 = _export;
var $includes = arrayIncludes.includes;
var addToUnscopables$1 = addToUnscopables$2;
var arrayMethodUsesToLength = arrayMethodUsesToLength$1;

var USES_TO_LENGTH = arrayMethodUsesToLength('indexOf', { ACCESSORS: true, 1: 0 });

// `Array.prototype.includes` method
// https://tc39.github.io/ecma262/#sec-array.prototype.includes
$$3({ target: 'Array', proto: true, forced: !USES_TO_LENGTH }, {
  includes: function includes(el /* , fromIndex = 0 */) {
    return $includes(this, el, arguments.length > 1 ? arguments[1] : undefined);
  }
});

// https://tc39.github.io/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables$1('includes');

var defaultTheme = {
  name: 'default',
  lightColor: '#F8D7DA',
  color: brandColor,
  hover: brandHover,
  white: white,
  black: black,
  grays: grays,
  colors: colors,
  label: {
    text: grays[1],
    optionalText: text.supporting,
    supportingText: text.supporting
  },
  header: {
    background: '#161616',
    text: '#f4f4f4',
    headerGlobalAction: {
      fill: '#ffffff'
    }
  },
  sideNav: {
    background: 'transparent',
    active: 'transparent',
    hover: '#e5e5e5'
  },
  text: grays[1],
  title: {
    h4: 'hsl(202, 57%, 15%)',
    h5: 'hsl(201, 23%, 34%)'
  }
};

var blueTheme = {
  name: 'blue',
  color: '#37B9F1',
  hover: 'rgb(34, 139, 230)'
};

var tealTheme = {
  name: 'teal',
  color: 'rgb(48, 144, 142)',
  hover: 'rgb(44, 122, 123)'
};

var ThemeContext = /*#__PURE__*/createContext({});

function useThemeContext() {
  var _a = useContext(ThemeContext),
      theme = _a.theme,
      onThemeSelected = _a.onThemeSelected;

  var setTheme = function setTheme(theme) {
    onThemeSelected(theme);
  };

  if (!theme) {
    return {
      theme: defaultTheme,
      setTheme: setTheme
    };
  }

  return {
    theme: theme,
    setTheme: setTheme
  };
}

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var EdeneTheme = function EdeneTheme(_a) {
  var userTheme = _a.theme,
      children = _a.children;

  var _b = useState(),
      themeValue = _b[0],
      setThemeValue = _b[1];

  var onThemeSelected = function onThemeSelected(theme) {
    setThemeValue(theme);
  };

  var theme = __assign(__assign(__assign({}, defaultTheme), userTheme), themeValue);

  return jsx(ThemeContext.Provider, __assign({
    value: {
      theme: theme,
      onThemeSelected: onThemeSelected
    }
  }, {
    children: children
  }));
};

var theme = __assign({}, defaultTheme);

var ThemeDecorator = function ThemeDecorator(storyFn) {
  return jsx(EdeneTheme, __assign({
    theme: theme
  }, {
    children: storyFn()
  }));
};

var COMPONENT_COLORS = ['success', 'info', 'danger', 'gray'];

var isOfComponentColors = function isOfComponentColors(color) {
  return ['success', 'info', 'danger', 'dark', 'gray', 'transparent'].includes(color);
};

var getLightenColor = function getLightenColor(_a) {
  var color = _a.color,
      _b = _a.theme,
      theme = _b === void 0 ? defaultTheme : _b;
  if (!color || color === 'brand') return theme.lightColor;
  if (isOfComponentColors(color)) return colorsPalette[color].light;
  return color;
};
var getColor = function getColor(_a) {
  var color = _a.color,
      _b = _a.theme,
      theme = _b === void 0 ? defaultTheme : _b;
  if (!color || color === 'primary' || color === 'brand') return theme.color;
  if (isOfComponentColors(color)) return colorsPalette[color].color;
  return color;
};
var getDarkenColor = function getDarkenColor(_a) {
  var color = _a.color,
      _b = _a.theme,
      theme = _b === void 0 ? defaultTheme : _b;
  if (!color || color === 'brand') return theme.hover;
  if (isOfComponentColors(color)) return colorsPalette[color].hover;
  return color;
};

var shadows = {
  primary: '0 0.1px 0.3px rgba(0, 0, 0, 0.022), 0 0.1px 0.7px rgba(0, 0, 0, 0.032), 0 0.3px 1.3px rgba(0, 0, 0, 0.04), 0 0.4px 2.2px rgba(0, 0, 0, 0.048), 0 0.8px 4.2px rgba(0, 0, 0, 0.058), 0 2px 10px rgba(0, 0, 0, 0.08)',
  lighest: '0 1px 3px hsla(0, 0%, 0%, .12), 0 1px 2px hsla(0, 0%, 0%, .24)',
  light: '0 3px 6px hsla(0, 0%, 0%, .15), 0 2px 4px hsla(0, 0%, 0%, .12)',
  regular: '0 10px 20px hsla(0, 0%, 0%, .15), 0 3px 6px hsla(0, 0%, 0%, .10)',
  dark: '0 15px 25px hsla(0, 0%, 0%, .15), 0 5px 10px hsla(0, 0%, 0%, .5))',
  darkest: '0 20px 40px hsla(0, 0%, 0%, .2)'
};

var buttonSize = {
  xsmall: {
    font: '12px',
    padding: 2
  },
  small: {
    font: '14px',
    padding: 3
  },
  medium: {
    font: '16px',
    padding: 4
  },
  large: {
    font: '18px',
    padding: 6
  }
};
var iconSize = {
  xsmall: 12,
  small: 16,
  medium: 20,
  large: 28,
  big: 48
}; // momentarily

var size = {
  small: 24,
  medium: 36,
  large: 44
};
var height = {
  ctaSmall: size.small,
  ctaMedium: size.medium,
  ctaLarge: size.large,
  inputSmall: size.small,
  inputMedium: size.medium,
  inputLarge: size.large,
  iconXsmall: iconSize.xsmall,
  iconSmall: iconSize.small,
  iconMedium: iconSize.medium,
  iconLarge: iconSize.large,
  iconBig: iconSize.big
};

var transitions = {
  short: '.1s ease-in-out',
  medium: '.3s ease-in-out',
  long: '.65s ease-in-out'
};

var iterators = {};

var requireObjectCoercible = requireObjectCoercible$2;

// `ToObject` abstract operation
// https://tc39.github.io/ecma262/#sec-toobject
var toObject$2 = function (argument) {
  return Object(requireObjectCoercible(argument));
};

var fails$1 = fails$8;

var correctPrototypeGetter = !fails$1(function () {
  function F() { /* empty */ }
  F.prototype.constructor = null;
  return Object.getPrototypeOf(new F()) !== F.prototype;
});

var has$2 = has$a;
var toObject$1 = toObject$2;
var sharedKey = sharedKey$3;
var CORRECT_PROTOTYPE_GETTER = correctPrototypeGetter;

var IE_PROTO = sharedKey('IE_PROTO');
var ObjectPrototype = Object.prototype;

// `Object.getPrototypeOf` method
// https://tc39.github.io/ecma262/#sec-object.getprototypeof
var objectGetPrototypeOf = CORRECT_PROTOTYPE_GETTER ? Object.getPrototypeOf : function (O) {
  O = toObject$1(O);
  if (has$2(O, IE_PROTO)) return O[IE_PROTO];
  if (typeof O.constructor == 'function' && O instanceof O.constructor) {
    return O.constructor.prototype;
  } return O instanceof Object ? ObjectPrototype : null;
};

var getPrototypeOf$1 = objectGetPrototypeOf;
var createNonEnumerableProperty$1 = createNonEnumerableProperty$6;
var has$1 = has$a;
var wellKnownSymbol$6 = wellKnownSymbol$8;

var ITERATOR$3 = wellKnownSymbol$6('iterator');
var BUGGY_SAFARI_ITERATORS$1 = false;

var returnThis$2 = function () { return this; };

// `%IteratorPrototype%` object
// https://tc39.github.io/ecma262/#sec-%iteratorprototype%-object
var IteratorPrototype$2, PrototypeOfArrayIteratorPrototype, arrayIterator;

if ([].keys) {
  arrayIterator = [].keys();
  // Safari 8 has buggy iterators w/o `next`
  if (!('next' in arrayIterator)) BUGGY_SAFARI_ITERATORS$1 = true;
  else {
    PrototypeOfArrayIteratorPrototype = getPrototypeOf$1(getPrototypeOf$1(arrayIterator));
    if (PrototypeOfArrayIteratorPrototype !== Object.prototype) IteratorPrototype$2 = PrototypeOfArrayIteratorPrototype;
  }
}

if (IteratorPrototype$2 == undefined) IteratorPrototype$2 = {};

// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()
if (!has$1(IteratorPrototype$2, ITERATOR$3)) {
  createNonEnumerableProperty$1(IteratorPrototype$2, ITERATOR$3, returnThis$2);
}

var iteratorsCore = {
  IteratorPrototype: IteratorPrototype$2,
  BUGGY_SAFARI_ITERATORS: BUGGY_SAFARI_ITERATORS$1
};

var defineProperty$1 = objectDefineProperty.f;
var has = has$a;
var wellKnownSymbol$5 = wellKnownSymbol$8;

var TO_STRING_TAG$2 = wellKnownSymbol$5('toStringTag');

var setToStringTag$2 = function (it, TAG, STATIC) {
  if (it && !has(it = STATIC ? it : it.prototype, TO_STRING_TAG$2)) {
    defineProperty$1(it, TO_STRING_TAG$2, { configurable: true, value: TAG });
  }
};

var IteratorPrototype$1 = iteratorsCore.IteratorPrototype;
var create = objectCreate;
var createPropertyDescriptor$1 = createPropertyDescriptor$4;
var setToStringTag$1 = setToStringTag$2;
var Iterators$4 = iterators;

var returnThis$1 = function () { return this; };

var createIteratorConstructor$1 = function (IteratorConstructor, NAME, next) {
  var TO_STRING_TAG = NAME + ' Iterator';
  IteratorConstructor.prototype = create(IteratorPrototype$1, { next: createPropertyDescriptor$1(1, next) });
  setToStringTag$1(IteratorConstructor, TO_STRING_TAG, false);
  Iterators$4[TO_STRING_TAG] = returnThis$1;
  return IteratorConstructor;
};

var isObject = isObject$5;

var aPossiblePrototype$1 = function (it) {
  if (!isObject(it) && it !== null) {
    throw TypeError("Can't set " + String(it) + ' as a prototype');
  } return it;
};

var anObject$2 = anObject$7;
var aPossiblePrototype = aPossiblePrototype$1;

// `Object.setPrototypeOf` method
// https://tc39.github.io/ecma262/#sec-object.setprototypeof
// Works with __proto__ only. Old v8 can't work with null proto objects.
/* eslint-disable no-proto */
var objectSetPrototypeOf = Object.setPrototypeOf || ('__proto__' in {} ? function () {
  var CORRECT_SETTER = false;
  var test = {};
  var setter;
  try {
    setter = Object.getOwnPropertyDescriptor(Object.prototype, '__proto__').set;
    setter.call(test, []);
    CORRECT_SETTER = test instanceof Array;
  } catch (error) { /* empty */ }
  return function setPrototypeOf(O, proto) {
    anObject$2(O);
    aPossiblePrototype(proto);
    if (CORRECT_SETTER) setter.call(O, proto);
    else O.__proto__ = proto;
    return O;
  };
}() : undefined);

var $$2 = _export;
var createIteratorConstructor = createIteratorConstructor$1;
var getPrototypeOf = objectGetPrototypeOf;
var setPrototypeOf = objectSetPrototypeOf;
var setToStringTag = setToStringTag$2;
var createNonEnumerableProperty = createNonEnumerableProperty$6;
var redefine = redefine$2.exports;
var wellKnownSymbol$4 = wellKnownSymbol$8;
var Iterators$3 = iterators;
var IteratorsCore = iteratorsCore;

var IteratorPrototype = IteratorsCore.IteratorPrototype;
var BUGGY_SAFARI_ITERATORS = IteratorsCore.BUGGY_SAFARI_ITERATORS;
var ITERATOR$2 = wellKnownSymbol$4('iterator');
var KEYS = 'keys';
var VALUES = 'values';
var ENTRIES = 'entries';

var returnThis = function () { return this; };

var defineIterator$1 = function (Iterable, NAME, IteratorConstructor, next, DEFAULT, IS_SET, FORCED) {
  createIteratorConstructor(IteratorConstructor, NAME, next);

  var getIterationMethod = function (KIND) {
    if (KIND === DEFAULT && defaultIterator) return defaultIterator;
    if (!BUGGY_SAFARI_ITERATORS && KIND in IterablePrototype) return IterablePrototype[KIND];
    switch (KIND) {
      case KEYS: return function keys() { return new IteratorConstructor(this, KIND); };
      case VALUES: return function values() { return new IteratorConstructor(this, KIND); };
      case ENTRIES: return function entries() { return new IteratorConstructor(this, KIND); };
    } return function () { return new IteratorConstructor(this); };
  };

  var TO_STRING_TAG = NAME + ' Iterator';
  var INCORRECT_VALUES_NAME = false;
  var IterablePrototype = Iterable.prototype;
  var nativeIterator = IterablePrototype[ITERATOR$2]
    || IterablePrototype['@@iterator']
    || DEFAULT && IterablePrototype[DEFAULT];
  var defaultIterator = !BUGGY_SAFARI_ITERATORS && nativeIterator || getIterationMethod(DEFAULT);
  var anyNativeIterator = NAME == 'Array' ? IterablePrototype.entries || nativeIterator : nativeIterator;
  var CurrentIteratorPrototype, methods, KEY;

  // fix native
  if (anyNativeIterator) {
    CurrentIteratorPrototype = getPrototypeOf(anyNativeIterator.call(new Iterable()));
    if (IteratorPrototype !== Object.prototype && CurrentIteratorPrototype.next) {
      if (getPrototypeOf(CurrentIteratorPrototype) !== IteratorPrototype) {
        if (setPrototypeOf) {
          setPrototypeOf(CurrentIteratorPrototype, IteratorPrototype);
        } else if (typeof CurrentIteratorPrototype[ITERATOR$2] != 'function') {
          createNonEnumerableProperty(CurrentIteratorPrototype, ITERATOR$2, returnThis);
        }
      }
      // Set @@toStringTag to native iterators
      setToStringTag(CurrentIteratorPrototype, TO_STRING_TAG, true);
    }
  }

  // fix Array#{values, @@iterator}.name in V8 / FF
  if (DEFAULT == VALUES && nativeIterator && nativeIterator.name !== VALUES) {
    INCORRECT_VALUES_NAME = true;
    defaultIterator = function values() { return nativeIterator.call(this); };
  }

  // define iterator
  if (IterablePrototype[ITERATOR$2] !== defaultIterator) {
    createNonEnumerableProperty(IterablePrototype, ITERATOR$2, defaultIterator);
  }
  Iterators$3[NAME] = defaultIterator;

  // export additional methods
  if (DEFAULT) {
    methods = {
      values: getIterationMethod(VALUES),
      keys: IS_SET ? defaultIterator : getIterationMethod(KEYS),
      entries: getIterationMethod(ENTRIES)
    };
    if (FORCED) for (KEY in methods) {
      if (BUGGY_SAFARI_ITERATORS || INCORRECT_VALUES_NAME || !(KEY in IterablePrototype)) {
        redefine(IterablePrototype, KEY, methods[KEY]);
      }
    } else $$2({ target: NAME, proto: true, forced: BUGGY_SAFARI_ITERATORS || INCORRECT_VALUES_NAME }, methods);
  }

  return methods;
};

var toIndexedObject = toIndexedObject$4;
var addToUnscopables = addToUnscopables$2;
var Iterators$2 = iterators;
var InternalStateModule = internalState;
var defineIterator = defineIterator$1;

var ARRAY_ITERATOR = 'Array Iterator';
var setInternalState = InternalStateModule.set;
var getInternalState = InternalStateModule.getterFor(ARRAY_ITERATOR);

// `Array.prototype.entries` method
// https://tc39.github.io/ecma262/#sec-array.prototype.entries
// `Array.prototype.keys` method
// https://tc39.github.io/ecma262/#sec-array.prototype.keys
// `Array.prototype.values` method
// https://tc39.github.io/ecma262/#sec-array.prototype.values
// `Array.prototype[@@iterator]` method
// https://tc39.github.io/ecma262/#sec-array.prototype-@@iterator
// `CreateArrayIterator` internal method
// https://tc39.github.io/ecma262/#sec-createarrayiterator
defineIterator(Array, 'Array', function (iterated, kind) {
  setInternalState(this, {
    type: ARRAY_ITERATOR,
    target: toIndexedObject(iterated), // target
    index: 0,                          // next index
    kind: kind                         // kind
  });
// `%ArrayIteratorPrototype%.next` method
// https://tc39.github.io/ecma262/#sec-%arrayiteratorprototype%.next
}, function () {
  var state = getInternalState(this);
  var target = state.target;
  var kind = state.kind;
  var index = state.index++;
  if (!target || index >= target.length) {
    state.target = undefined;
    return { value: undefined, done: true };
  }
  if (kind == 'keys') return { value: index, done: false };
  if (kind == 'values') return { value: target[index], done: false };
  return { value: [index, target[index]], done: false };
}, 'values');

// argumentsList[@@iterator] is %ArrayProto_values%
// https://tc39.github.io/ecma262/#sec-createunmappedargumentsobject
// https://tc39.github.io/ecma262/#sec-createmappedargumentsobject
Iterators$2.Arguments = Iterators$2.Array;

// https://tc39.github.io/ecma262/#sec-array.prototype-@@unscopables
addToUnscopables('keys');
addToUnscopables('values');
addToUnscopables('entries');

var iterate$2 = {exports: {}};

var wellKnownSymbol$3 = wellKnownSymbol$8;
var Iterators$1 = iterators;

var ITERATOR$1 = wellKnownSymbol$3('iterator');
var ArrayPrototype = Array.prototype;

// check on default Array iterator
var isArrayIteratorMethod$1 = function (it) {
  return it !== undefined && (Iterators$1.Array === it || ArrayPrototype[ITERATOR$1] === it);
};

var aFunction$1 = function (it) {
  if (typeof it != 'function') {
    throw TypeError(String(it) + ' is not a function');
  } return it;
};

var aFunction = aFunction$1;

// optional / simple context binding
var functionBindContext = function (fn, that, length) {
  aFunction(fn);
  if (that === undefined) return fn;
  switch (length) {
    case 0: return function () {
      return fn.call(that);
    };
    case 1: return function (a) {
      return fn.call(that, a);
    };
    case 2: return function (a, b) {
      return fn.call(that, a, b);
    };
    case 3: return function (a, b, c) {
      return fn.call(that, a, b, c);
    };
  }
  return function (/* ...args */) {
    return fn.apply(that, arguments);
  };
};

var wellKnownSymbol$2 = wellKnownSymbol$8;

var TO_STRING_TAG$1 = wellKnownSymbol$2('toStringTag');
var test = {};

test[TO_STRING_TAG$1] = 'z';

var toStringTagSupport = String(test) === '[object z]';

var TO_STRING_TAG_SUPPORT = toStringTagSupport;
var classofRaw = classofRaw$1;
var wellKnownSymbol$1 = wellKnownSymbol$8;

var TO_STRING_TAG = wellKnownSymbol$1('toStringTag');
// ES3 wrong here
var CORRECT_ARGUMENTS = classofRaw(function () { return arguments; }()) == 'Arguments';

// fallback for IE11 Script Access Denied error
var tryGet = function (it, key) {
  try {
    return it[key];
  } catch (error) { /* empty */ }
};

// getting tag from ES6+ `Object.prototype.toString`
var classof$1 = TO_STRING_TAG_SUPPORT ? classofRaw : function (it) {
  var O, tag, result;
  return it === undefined ? 'Undefined' : it === null ? 'Null'
    // @@toStringTag case
    : typeof (tag = tryGet(O = Object(it), TO_STRING_TAG)) == 'string' ? tag
    // builtinTag case
    : CORRECT_ARGUMENTS ? classofRaw(O)
    // ES3 arguments fallback
    : (result = classofRaw(O)) == 'Object' && typeof O.callee == 'function' ? 'Arguments' : result;
};

var classof = classof$1;
var Iterators = iterators;
var wellKnownSymbol = wellKnownSymbol$8;

var ITERATOR = wellKnownSymbol('iterator');

var getIteratorMethod$1 = function (it) {
  if (it != undefined) return it[ITERATOR]
    || it['@@iterator']
    || Iterators[classof(it)];
};

var anObject$1 = anObject$7;

// call something on iterator step with safe closing on error
var callWithSafeIterationClosing$1 = function (iterator, fn, value, ENTRIES) {
  try {
    return ENTRIES ? fn(anObject$1(value)[0], value[1]) : fn(value);
  // 7.4.6 IteratorClose(iterator, completion)
  } catch (error) {
    var returnMethod = iterator['return'];
    if (returnMethod !== undefined) anObject$1(returnMethod.call(iterator));
    throw error;
  }
};

var anObject = anObject$7;
var isArrayIteratorMethod = isArrayIteratorMethod$1;
var toLength = toLength$2;
var bind = functionBindContext;
var getIteratorMethod = getIteratorMethod$1;
var callWithSafeIterationClosing = callWithSafeIterationClosing$1;

var Result = function (stopped, result) {
  this.stopped = stopped;
  this.result = result;
};

var iterate$1 = iterate$2.exports = function (iterable, fn, that, AS_ENTRIES, IS_ITERATOR) {
  var boundFunction = bind(fn, that, AS_ENTRIES ? 2 : 1);
  var iterator, iterFn, index, length, result, next, step;

  if (IS_ITERATOR) {
    iterator = iterable;
  } else {
    iterFn = getIteratorMethod(iterable);
    if (typeof iterFn != 'function') throw TypeError('Target is not iterable');
    // optimisation for array iterators
    if (isArrayIteratorMethod(iterFn)) {
      for (index = 0, length = toLength(iterable.length); length > index; index++) {
        result = AS_ENTRIES
          ? boundFunction(anObject(step = iterable[index])[0], step[1])
          : boundFunction(iterable[index]);
        if (result && result instanceof Result) return result;
      } return new Result(false);
    }
    iterator = iterFn.call(iterable);
  }

  next = iterator.next;
  while (!(step = next.call(iterator)).done) {
    result = callWithSafeIterationClosing(iterator, boundFunction, step.value, AS_ENTRIES);
    if (typeof result == 'object' && result && result instanceof Result) return result;
  } return new Result(false);
};

iterate$1.stop = function (result) {
  return new Result(true, result);
};

var toPrimitive = toPrimitive$3;
var definePropertyModule = objectDefineProperty;
var createPropertyDescriptor = createPropertyDescriptor$4;

var createProperty$1 = function (object, key, value) {
  var propertyKey = toPrimitive(key);
  if (propertyKey in object) definePropertyModule.f(object, propertyKey, createPropertyDescriptor(0, value));
  else object[propertyKey] = value;
};

var $$1 = _export;
var iterate = iterate$2.exports;
var createProperty = createProperty$1;

// `Object.fromEntries` method
// https://github.com/tc39/proposal-object-from-entries
$$1({ target: 'Object', stat: true }, {
  fromEntries: function fromEntries(iterable) {
    var obj = {};
    iterate(iterable, function (k, v) {
      createProperty(obj, k, v);
    }, undefined, true);
    return obj;
  }
});

var DESCRIPTORS = descriptors;
var fails = fails$8;
var objectKeys = objectKeys$2;
var getOwnPropertySymbolsModule = objectGetOwnPropertySymbols;
var propertyIsEnumerableModule = objectPropertyIsEnumerable;
var toObject = toObject$2;
var IndexedObject = indexedObject;

var nativeAssign = Object.assign;
var defineProperty = Object.defineProperty;

// `Object.assign` method
// https://tc39.github.io/ecma262/#sec-object.assign
var objectAssign = !nativeAssign || fails(function () {
  // should have correct order of operations (Edge bug)
  if (DESCRIPTORS && nativeAssign({ b: 1 }, nativeAssign(defineProperty({}, 'a', {
    enumerable: true,
    get: function () {
      defineProperty(this, 'b', {
        value: 3,
        enumerable: false
      });
    }
  }), { b: 2 })).b !== 1) return true;
  // should work with symbols and should have deterministic property order (V8 bug)
  var A = {};
  var B = {};
  // eslint-disable-next-line no-undef
  var symbol = Symbol();
  var alphabet = 'abcdefghijklmnopqrst';
  A[symbol] = 7;
  alphabet.split('').forEach(function (chr) { B[chr] = chr; });
  return nativeAssign({}, A)[symbol] != 7 || objectKeys(nativeAssign({}, B)).join('') != alphabet;
}) ? function assign(target, source) { // eslint-disable-line no-unused-vars
  var T = toObject(target);
  var argumentsLength = arguments.length;
  var index = 1;
  var getOwnPropertySymbols = getOwnPropertySymbolsModule.f;
  var propertyIsEnumerable = propertyIsEnumerableModule.f;
  while (argumentsLength > index) {
    var S = IndexedObject(arguments[index++]);
    var keys = getOwnPropertySymbols ? objectKeys(S).concat(getOwnPropertySymbols(S)) : objectKeys(S);
    var length = keys.length;
    var j = 0;
    var key;
    while (length > j) {
      key = keys[j++];
      if (!DESCRIPTORS || propertyIsEnumerable.call(S, key)) T[key] = S[key];
    }
  } return T;
} : nativeAssign;

var $ = _export;
var assign = objectAssign;

// `Object.assign` method
// https://tc39.github.io/ecma262/#sec-object.assign
$({ target: 'Object', stat: true, forced: Object.assign !== assign }, {
  assign: assign
});

var fontSizes = [10, 12, 14, 15, 16, 18, 20, 24, 32];
var fonts = {
  titlepiece: 'GT Guardian Headingpiece, Georgia, serif',
  headlineSerif: 'Merriweather, Arial, sans-serif',
  bodySerif: 'GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif',
  bodySans: 'Lato, Arial, sans-serif'
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [400, 600];
/** @deprecated */

var titlepieceSizes = {
  small: fontSizes[8],
  medium: fontSizes[9],
  large: fontSizes[10]
};
var headlineSizes = {
  h1: fontSizes[8],
  h2: fontSizes[7],
  h3: fontSizes[6],
  h4: fontSizes[5],
  h5: fontSizes[6],
  h6: fontSizes[4]
};
var bodySizes = {
  small: fontSizes[2],
  medium: fontSizes[3]
};
var textSansSizes = {
  xxsmall: fontSizes[0],
  xsmall: fontSizes[1],
  small: fontSizes[2],
  medium: fontSizes[3],
  large: fontSizes[4],
  xlarge: fontSizes[5],
  xxlarge: fontSizes[6]
};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  regular: fontWeights[0],
  bold: fontWeights[1]
};
var availableFonts = {
  titlepiece: {
    bold: {
      // TODO: make hasItalic work
      hasItalic: false
    }
  },
  headline: {
    regular: {
      hasItalic: false
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: false
    },
    bold: {
      hasItalic: false
    }
  },
  textSans: {
    regular: {
      hasItalic: false
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

function getFontStyle(font, fontStyle) {
  switch (fontStyle) {
    case 'italic':
      return (font === null || font === void 0 ? void 0 : font.hasItalic) ? 'italic' : null;

    case 'normal':
      return 'normal';

    case null:
    default:
      return null;
  }
}

var fs = function fs(category) {
  return function (level, _a) {
    var lineHeight = _a.lineHeight,
        fontWeight = _a.fontWeight,
        fontStyle = _a.fontStyle,
        unit = _a.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = fontSizeMapping[category][level];
    var lineHeightValue = unit === 'px' ? // line-height is defined as a unitless value, so we multiply
    // by the element's font-size in px to get the px value
    "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : '';
    var fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var headlineDefaults = {
  lineHeight: 'tight',
  fontWeight: 'regular',
  fontStyle: null,
  unit: 'rem'
};
var headlineFs = fs('headline');
var headline$1 = {
  h1: function (options) {
    return headlineFs('xlarge', Object.assign({}, headlineDefaults, options));
  },
  h2: function (options) {
    return headlineFs('large', Object.assign({}, headlineDefaults, options));
  },
  h3: function (options) {
    return headlineFs('medium', Object.assign({}, headlineDefaults, options));
  },
  h4: function (options) {
    return headlineFs('small', Object.assign({}, headlineDefaults, options));
  },
  h5: function (options) {
    return headlineFs('xsmall', Object.assign({}, headlineDefaults, options));
  },
  h6: function (options) {
    return headlineFs('xxsmall', Object.assign({}, headlineDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: 'loose',
  fontWeight: 'regular',
  fontStyle: null,
  unit: 'rem'
};
var textSansFs = fs('textSans');
var textSans$1 = {
  xxsmall: function (options) {
    return textSansFs('xxsmall', Object.assign({}, textSansDefaults, options));
  },
  xsmall: function (options) {
    return textSansFs('xsmall', Object.assign({}, textSansDefaults, options));
  },
  small: function (options) {
    return textSansFs('small', Object.assign({}, textSansDefaults, options));
  },
  medium: function (options) {
    return textSansFs('medium', Object.assign({}, textSansDefaults, options));
  },
  large: function (options) {
    return textSansFs('large', Object.assign({}, textSansDefaults, options));
  },
  xlarge: function (options) {
    return textSansFs('xlarge', Object.assign({}, textSansDefaults, options));
  },
  xxlarge: function (options) {
    return textSansFs('xxlarge', Object.assign({}, textSansDefaults, options));
  },
  xxxlarge: function (options) {
    return textSansFs('xxxlarge', Object.assign({}, textSansDefaults, options));
  }
};

var objectStylesToString = function objectStylesToString(_a) {
  var fontFamily = _a.fontFamily,
      fontSize = _a.fontSize,
      lineHeight = _a.lineHeight,
      fontWeight = _a.fontWeight,
      fontStyle = _a.fontStyle;
  return "\n\tfont-family: ".concat(fontFamily, ";\n\tfont-size: ").concat(typeof fontSize === 'number' ? "".concat(fontSize, "px") : fontSize, ";\n\tline-height: ").concat(lineHeight, ";\n\t").concat(fontWeight ? "font-weight: ".concat(fontWeight) : '', ";\n\t").concat(fontStyle ? "font-style: ".concat(fontStyle) : '', ";\n");
};

var headline = Object.fromEntries(Object.entries(headline$1).map(function (_a) {
  var key = _a[0],
      func = _a[1];
  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var textSans = Object.fromEntries(Object.entries(textSans$1).map(function (_a) {
  var key = _a[0],
      func = _a[1];
  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));

// Icon
var ICON_VARIANTS = ['filled', 'outlined'];

export { COMPONENT_COLORS, EdeneTheme, ICON_VARIANTS, ThemeContext, ThemeDecorator, altBackground, altFill, altText, background, black, blueTheme, border, brandColor, brandHover, breakpoints, buttonSize, colors, colorsPalette, defaultTheme, descriptionId, disabled, error, fill, focus, focusHalo, from, generateSourceId, getColor, getDarkenColor, getLightenColor, grays, headline, height, iconSize, info, isOfComponentColors, shadows, size, success, tealTheme, text, textSans, transitions, until, useThemeContext, visuallyHidden, white };
